#
# File: osxapp.mk
# Creator: George Ferguson
# Created: Mon Jun 14 16:18:48 2010
# Time-stamp: <Fri Jun 18 15:24:35 EDT 2010 ferguson>
#
# Create an OSX app from a Java jar
#
# @see http://developer.apple.com/mac/library/documentation/Java/Conceptual/Java14Development/00-Intro/JavaDevelopment.html
# @see http://developer.apple.com/mac/library/documentation/Java/Reference/Java_InfoplistRef/Articles/JavaDictionaryInfo.plistKeys.html
# @see http://developer.apple.com/Mac/library/documentation/Java/Reference/Java_PropertiesRef/Articles/JavaSystemProperties.html
#
# Copyright 2010 George Ferguson, ferguson@cs.rochester.edu.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

# Definitely change these
Name               = URCS WordNet Browser
MainClass          = $(PROJECT_PACKAGE).browser.BrowserOSX
Identifier         = $(PROJECT_PACKAGE).browser
Version            = $(PROJECT_VERSION)
SplashFile	   = $(notdir $(PROJECT_SPLASH))

# Possibly change these (although defaults should be good)
IconFile           = $(Name).icns
#JarFile            = $(Name).jar
JarFile            = $(JARFILE)
Signature          = ????
GetInfoString      = $(Name) v$(Version)
ShortVersionString = $(Name)

# Unlikely to need to change these
Executable = /System/Library/Frameworks/JavaVM.framework/Versions/Current/Resources/MacOS/JavaApplicationStub
JVMVersion = 1.6+

#
# Nothing to change below here
#
APPDIR     = '$(Name).app'

# Bundle-building target
bundle: Info.plist
	# Proper directory hierarchy
	rm -rf $(APPDIR)
	mkdir -p $(APPDIR)/Contents/MacOS
	mkdir -p $(APPDIR)/Contents/Resources/Java
	# Copy executable
	cp -p '$(Executable)' $(APPDIR)/Contents/MacOS/
	# Info.plist file
	cp -p Info.plist $(APPDIR)/Contents
	# PkgInfo file
	echo 'APPL$(Signature)' >$(APPDIR)/PkgInfo
	# Icon file
	cp -p '$(IconFile)' $(APPDIR)/Contents/Resources
	# Jar file
	cp -p ../'$(JarFile)' $(APPDIR)/Contents/Resources/Java
	# Set Finder bundle bit (ignore error if devtools not installed)
	-/Developer/Tools/SetFile -a B $(APPDIR)
	# Setup splash screen (also in jar but...)
	cp -p '$(PROJECT_SPLASH)' $(APPDIR)/Contents/Resources/Java/'$(SplashFile)'
	# Setup help
	mkdir -p $(APPDIR)/Contents/Resources/English.lproj/'$(Name) Help'
	cp -p help/index.html $(APPDIR)/Contents/Resources/English.lproj/'$(Name) Help'

# Plist-building target
Info.plist: Info.plist.in Makefile
	sed -e 's!@Executable@!$(notdir $(Executable))!' \
	    -e 's!@GetInfoString@!$(GetInfoString)!' \
	    -e 's!@IconFile@!$(notdir $(IconFile))!' \
	    -e 's!@Identifier@!$(Identifier)!' \
	    -e 's!@Name@!$(Name)!' \
	    -e 's!@ShortVersionString@!$(ShortVersionString)!' \
	    -e 's!@Signature@!$(Signature)!' \
	    -e 's!@Version@!$(Version)!' \
	    -e 's!@JarFile@!$(notdir $(JarFile))!' \
	    -e 's!@JVMVersion@!$(JVMVersion)!' \
	    -e 's!@MainClass@!$(MainClass)!' \
	    -e 's!@SplashFile@!$(SplashFile)!' \
	    Info.plist.in >Info.plist

clean::
	rm -rf $(APPDIR) Info.plist
